/* BlockedEmails.c generated by valac 0.56.19, the Vala compiler
 * generated from BlockedEmails.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE (tuba_views_admin_page_base_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))

typedef struct _TubaViewsAdminPageBase TubaViewsAdminPageBase;
typedef struct _TubaViewsAdminPageBaseClass TubaViewsAdminPageBaseClass;
typedef struct _TubaViewsAdminPageBasePrivate TubaViewsAdminPageBasePrivate;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS (tuba_views_admin_page_blocked_emails_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmails))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmailsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_EMAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_EMAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmailsClass))

typedef struct _TubaViewsAdminPageBlockedEmails TubaViewsAdminPageBlockedEmails;
typedef struct _TubaViewsAdminPageBlockedEmailsClass TubaViewsAdminPageBlockedEmailsClass;
typedef struct _TubaViewsAdminPageBlockedEmailsPrivate TubaViewsAdminPageBlockedEmailsPrivate;

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE (tuba_views_admin_timeline_pagination_timeline_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))

typedef struct _TubaViewsAdminTimelinePaginationTimeline TubaViewsAdminTimelinePaginationTimeline;
typedef struct _TubaViewsAdminTimelinePaginationTimelineClass TubaViewsAdminTimelinePaginationTimelineClass;

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN (tuba_views_admin_timeline_email_domain_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_EMAIL_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN, TubaViewsAdminTimelineEmailDomain))
#define TUBA_VIEWS_ADMIN_TIMELINE_EMAIL_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN, TubaViewsAdminTimelineEmailDomainClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_EMAIL_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_EMAIL_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN))
#define TUBA_VIEWS_ADMIN_TIMELINE_EMAIL_DOMAIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_EMAIL_DOMAIN, TubaViewsAdminTimelineEmailDomainClass))

typedef struct _TubaViewsAdminTimelineEmailDomain TubaViewsAdminTimelineEmailDomain;
typedef struct _TubaViewsAdminTimelineEmailDomainClass TubaViewsAdminTimelineEmailDomainClass;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_blocked_emails_properties[TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_DIALOGS_ADMIN_TYPE_WINDOW (tuba_dialogs_admin_window_get_type ())
#define TUBA_DIALOGS_ADMIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow))
#define TUBA_DIALOGS_ADMIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))

typedef struct _TubaDialogsAdminWindow TubaDialogsAdminWindow;
typedef struct _TubaDialogsAdminWindowClass TubaDialogsAdminWindowClass;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaViewsAdminPageBlockedEmailsOnActionBarActivateData TubaViewsAdminPageBlockedEmailsOnActionBarActivateData;

struct _TubaViewsAdminPageBase {
	AdwNavigationPage parent_instance;
	TubaViewsAdminPageBasePrivate * priv;
	AdwHeaderBar* headerbar;
	AdwToolbarView* toolbar_view;
};

struct _TubaViewsAdminPageBaseClass {
	AdwNavigationPageClass parent_class;
	void (*add_to_page) (TubaViewsAdminPageBase* self, AdwPreferencesGroup* group);
};

struct _TubaViewsAdminPageBlockedEmails {
	TubaViewsAdminPageBase parent_instance;
	TubaViewsAdminPageBlockedEmailsPrivate * priv;
};

struct _TubaViewsAdminPageBlockedEmailsClass {
	TubaViewsAdminPageBaseClass parent_class;
};

struct _TubaViewsAdminPageBlockedEmailsPrivate {
	GtkEntry* child_entry;
	GtkButton* add_button;
	TubaViewsAdminTimelineEmailDomain* pagination_timeline;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsAdminPageBlockedEmailsOnActionBarActivateData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminPageBlockedEmails* self;
	GtkEntryBuffer* buffer;
	guint _tmp0_;
	guint _tmp1_;
	gchar* domain;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	AdwAlertDialog* dlg;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	AdwAlertDialog* _tmp8_;
	AdwAlertDialog* _tmp9_;
	AdwAlertDialog* _tmp10_;
	AdwAlertDialog* _tmp11_;
	AdwAlertDialog* _tmp12_;
	AdwAlertDialog* _tmp13_;
	AdwAlertDialog* _tmp14_;
	TubaDialogsAdminWindow* _tmp15_;
	TubaDialogsAdminWindow* _tmp16_;
	const gchar* _tmp17_;
	TubaRequestV2* req;
	TubaAccountStore* _tmp18_;
	TubaInstanceAccount* _tmp19_;
	TubaInstanceAccount* _tmp20_;
	TubaInstanceAccount* _tmp21_;
	TubaRequestV2* _tmp22_;
	TubaRequestV2* _tmp23_;
	const gchar* _tmp24_;
	TubaRequestV2* _tmp25_;
	GInputStream* _tmp26_;
	GInputStream* _tmp27_;
	TubaViewsAdminTimelineEmailDomain* _tmp28_;
	GError* e;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	GError* _tmp31_;
	const gchar* _tmp32_;
	const gchar* _tmp33_;
	GError* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	GError* _tmp39_;
	GError* _tmp40_;
	const gchar* _tmp41_;
	guint8* _tmp42_;
	gint _tmp42__length1;
	gint _tmp43_;
	guint8* _tmp44_;
	gint _tmp44__length1;
	GError* _inner_error0_;
};

static gint TubaViewsAdminPageBlockedEmails_private_offset;
static gpointer tuba_views_admin_page_blocked_emails_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_views_admin_page_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBase, g_object_unref)
VALA_EXTERN GType tuba_views_admin_page_blocked_emails_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBlockedEmails, g_object_unref)
VALA_EXTERN GType tuba_views_admin_timeline_pagination_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelinePaginationTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_admin_timeline_email_domain_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelineEmailDomain, g_object_unref)
static void tuba_views_admin_page_blocked_emails_new_item_cb (TubaViewsAdminPageBlockedEmails* self);
static void tuba_views_admin_page_blocked_emails_on_action_bar_activate (TubaViewsAdminPageBlockedEmails* self,
                                                                  GtkEntryBuffer* buffer,
                                                                  GAsyncReadyCallback _callback_,
                                                                  gpointer _user_data_);
static void tuba_views_admin_page_blocked_emails_on_action_bar_activate_finish (TubaViewsAdminPageBlockedEmails* self,
                                                                         GAsyncResult* _res_);
static void tuba_views_admin_page_blocked_emails_on_entry_changed (TubaViewsAdminPageBlockedEmails* self);
static void tuba_views_admin_page_blocked_emails_on_action_bar_activate_data_free (gpointer _data);
static gboolean tuba_views_admin_page_blocked_emails_on_action_bar_activate_co (TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_);
VALA_EXTERN GType tuba_dialogs_admin_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminWindow, g_object_unref)
VALA_EXTERN TubaDialogsAdminWindow* tuba_views_admin_page_base_get_admin_window (TubaViewsAdminPageBase* self);
static void tuba_views_admin_page_blocked_emails_on_action_bar_activate_ready (GObject* source_object,
                                                                        GAsyncResult* _res_,
                                                                        gpointer _user_data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_add_form_data (TubaRequestV2* self,
                                    const gchar* name,
                                    const gchar* val);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN void tuba_views_admin_page_base_on_error (TubaViewsAdminPageBase* self,
                                          gint code,
                                          const gchar* message);
VALA_EXTERN TubaViewsAdminPageBlockedEmails* tuba_views_admin_page_blocked_emails_new (void);
VALA_EXTERN TubaViewsAdminPageBlockedEmails* tuba_views_admin_page_blocked_emails_construct (GType object_type);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_new (void);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_construct (GType object_type);
static GObject * tuba_views_admin_page_blocked_emails_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static void _tuba_views_admin_page_blocked_emails_new_item_cb_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self);
static void _tuba_views_admin_page_blocked_emails_new_item_cb_gtk_entry_activate (GtkEntry* _sender,
                                                                           gpointer self);
static void _tuba_views_admin_page_blocked_emails_on_entry_changed_g_object_notify (GObject* _sender,
                                                                             GParamSpec* pspec,
                                                                             gpointer self);
VALA_EXTERN TubaViewsAdminTimelineEmailDomain* tuba_views_admin_timeline_email_domain_new (void);
VALA_EXTERN TubaViewsAdminTimelineEmailDomain* tuba_views_admin_timeline_email_domain_construct (GType object_type);
static void _tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error (TubaViewsAdminTimelinePaginationTimeline* _sender,
                                                                                                  gint code,
                                                                                                  const gchar* message,
                                                                                                  gpointer self);
VALA_EXTERN void tuba_views_admin_page_base_set_page (TubaViewsAdminPageBase* self,
                                          GtkWidget* value);
static void tuba_views_admin_page_blocked_emails_finalize (GObject * obj);
static GType tuba_views_admin_page_blocked_emails_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_views_admin_page_blocked_emails_get_instance_private (TubaViewsAdminPageBlockedEmails* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageBlockedEmails_private_offset);
}

static void
tuba_views_admin_page_blocked_emails_new_item_cb (TubaViewsAdminPageBlockedEmails* self)
{
	GtkEntry* _tmp0_;
	GtkEntryBuffer* _tmp1_;
	GtkEntryBuffer* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->child_entry;
	_tmp1_ = gtk_entry_get_buffer (_tmp0_);
	_tmp2_ = _tmp1_;
	tuba_views_admin_page_blocked_emails_on_action_bar_activate (self, _tmp2_, NULL, NULL);
}

static void
tuba_views_admin_page_blocked_emails_on_entry_changed (TubaViewsAdminPageBlockedEmails* self)
{
	GtkButton* _tmp0_;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->add_button;
	_tmp1_ = self->priv->child_entry;
	_tmp2_ = gtk_editable_get_text ((GtkEditable*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = strlen (_tmp3_);
	_tmp5_ = _tmp4_;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ > 0);
}

static void
tuba_views_admin_page_blocked_emails_on_action_bar_activate_data_free (gpointer _data)
{
	TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->buffer);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminPageBlockedEmailsOnActionBarActivateData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_views_admin_page_blocked_emails_on_action_bar_activate (TubaViewsAdminPageBlockedEmails* self,
                                                             GtkEntryBuffer* buffer,
                                                             GAsyncReadyCallback _callback_,
                                                             gpointer _user_data_)
{
	TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_;
	TubaViewsAdminPageBlockedEmails* _tmp0_;
	GtkEntryBuffer* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (buffer != NULL);
	_data_ = g_slice_new0 (TubaViewsAdminPageBlockedEmailsOnActionBarActivateData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_page_blocked_emails_on_action_bar_activate_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (buffer);
	_g_object_unref0 (_data_->buffer);
	_data_->buffer = _tmp1_;
	tuba_views_admin_page_blocked_emails_on_action_bar_activate_co (_data_);
}

static void
tuba_views_admin_page_blocked_emails_on_action_bar_activate_finish (TubaViewsAdminPageBlockedEmails* self,
                                                                    GAsyncResult* _res_)
{
	TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_page_blocked_emails_on_action_bar_activate_ready (GObject* source_object,
                                                                   GAsyncResult* _res_,
                                                                   gpointer _user_data_)
{
	TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_page_blocked_emails_on_action_bar_activate_co (_data_);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static guint8*
string_get_data (const gchar* self,
                 gint* result_length1)
{
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
	g_return_val_if_fail (self != NULL, NULL);
	res = (guint8*) self;
	res_length1 = -1;
	_res_size_ = res_length1;
	_tmp0_ = strlen (self);
	_tmp1_ = _tmp0_;
	res_length1 = (gint) _tmp1_;
	_tmp2_ = res;
	_tmp2__length1 = res_length1;
	if (result_length1) {
		*result_length1 = _tmp2__length1;
	}
	result = _tmp2_;
	return result;
}

static gboolean
tuba_views_admin_page_blocked_emails_on_action_bar_activate_co (TubaViewsAdminPageBlockedEmailsOnActionBarActivateData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		case 3:
		goto _state_3;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gtk_entry_buffer_get_length (_data_->buffer);
	_data_->_tmp1_ = _data_->_tmp0_;
	if (_data_->_tmp1_ > ((guint) 0)) {
		_data_->_tmp2_ = gtk_entry_buffer_get_text (_data_->buffer);
		_data_->_tmp3_ = _data_->_tmp2_;
		_data_->_tmp4_ = g_strdup (_data_->_tmp3_);
		_data_->domain = _data_->_tmp4_;
		_data_->_tmp5_ = _data_->domain;
		_data_->_tmp6_ = g_strdup_printf (_ ("Block %s?"), _data_->_tmp5_);
		_data_->_tmp7_ = _data_->_tmp6_;
		_data_->_tmp8_ = (AdwAlertDialog*) adw_alert_dialog_new (_data_->_tmp7_, _ ("This can be the domain name that shows up in the e-mail address or the" \
" MX record it uses. They will be checked upon sign-up."));
		g_object_ref_sink (_data_->_tmp8_);
		_data_->_tmp9_ = _data_->_tmp8_;
		_g_free0 (_data_->_tmp7_);
		_data_->dlg = _data_->_tmp9_;
		_data_->_tmp10_ = _data_->dlg;
		adw_alert_dialog_add_response (_data_->_tmp10_, "no", _ ("Cancel"));
		_data_->_tmp11_ = _data_->dlg;
		adw_alert_dialog_set_response_appearance (_data_->_tmp11_, "no", ADW_RESPONSE_DEFAULT);
		_data_->_tmp12_ = _data_->dlg;
		adw_alert_dialog_add_response (_data_->_tmp12_, "yes", _ ("Block"));
		_data_->_tmp13_ = _data_->dlg;
		adw_alert_dialog_set_response_appearance (_data_->_tmp13_, "yes", ADW_RESPONSE_DESTRUCTIVE);
		_data_->_tmp14_ = _data_->dlg;
		_data_->_tmp15_ = tuba_views_admin_page_base_get_admin_window ((TubaViewsAdminPageBase*) _data_->self);
		_data_->_tmp16_ = _data_->_tmp15_;
		_data_->_state_ = 1;
		adw_alert_dialog_choose (_data_->_tmp14_, (GtkWidget*) _data_->_tmp16_, NULL, tuba_views_admin_page_blocked_emails_on_action_bar_activate_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp17_ = adw_alert_dialog_choose_finish (_data_->_tmp14_, _data_->_res_);
		if (g_strcmp0 (_data_->_tmp17_, "yes") == 0) {
			_data_->_tmp18_ = tuba_accounts;
			_data_->_tmp19_ = tuba_account_store_get_active (_data_->_tmp18_);
			_data_->_tmp20_ = _data_->_tmp19_;
			_data_->_tmp21_ = _g_object_ref0 (_data_->_tmp20_);
			_data_->_tmp22_ = NULL;
			_data_->_tmp22_ = tuba_request_v2_new ("/api/v1/admin/email_domain_blocks", TUBA_REQUEST_V2_METHOD_POST);
			tuba_request_v2_set_account (_data_->_tmp22_, _data_->_tmp21_);
			_g_object_unref0 (_data_->_tmp21_);
			_data_->req = _data_->_tmp22_;
			_data_->_tmp23_ = _data_->req;
			_data_->_tmp24_ = _data_->domain;
			tuba_request_v2_add_form_data (_data_->_tmp23_, "domain", _data_->_tmp24_);
			{
				_data_->_tmp25_ = _data_->req;
				_data_->_state_ = 2;
				tuba_request_v2_exec (_data_->_tmp25_, tuba_views_admin_page_blocked_emails_on_action_bar_activate_ready, _data_);
				return FALSE;
				_state_2:
				_data_->_tmp26_ = tuba_request_v2_exec_finish (_data_->_tmp25_, _data_->_res_, NULL, &_data_->_inner_error0_);
				_data_->_tmp27_ = _data_->_tmp26_;
				_g_object_unref0 (_data_->_tmp27_);
				if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
					goto __catch0_g_error;
				}
				_data_->_tmp28_ = _data_->self->priv->pagination_timeline;
				_data_->_state_ = 3;
				tuba_views_admin_timeline_pagination_timeline_request ((TubaViewsAdminTimelinePaginationTimeline*) _data_->_tmp28_, tuba_views_admin_page_blocked_emails_on_action_bar_activate_ready, _data_);
				return FALSE;
				_state_3:
				tuba_views_admin_timeline_pagination_timeline_request_finish ((TubaViewsAdminTimelinePaginationTimeline*) _data_->_tmp28_, _data_->_res_);
			}
			goto __finally0;
			__catch0_g_error:
			{
				_data_->e = _data_->_inner_error0_;
				_data_->_inner_error0_ = NULL;
				_data_->_tmp29_ = _data_->domain;
				_data_->_tmp30_ = string_to_string (_data_->_tmp29_);
				_data_->_tmp31_ = _data_->e;
				_data_->_tmp32_ = _data_->_tmp31_->message;
				_data_->_tmp33_ = string_to_string (_data_->_tmp32_);
				_data_->_tmp34_ = _data_->e;
				_data_->_tmp35_ = g_strdup_printf ("%i", _data_->_tmp34_->code);
				_data_->_tmp36_ = _data_->_tmp35_;
				_data_->_tmp37_ = g_strconcat ("Error trying to block e-mail domain ", _data_->_tmp30_, ": ", _data_->_tmp33_, " ", _data_->_tmp36_, NULL);
				_data_->_tmp38_ = _data_->_tmp37_;
				g_warning ("BlockedEmails.vala:81: %s", _data_->_tmp38_);
				_g_free0 (_data_->_tmp38_);
				_g_free0 (_data_->_tmp36_);
				_data_->_tmp39_ = _data_->e;
				_data_->_tmp40_ = _data_->e;
				_data_->_tmp41_ = _data_->_tmp40_->message;
				tuba_views_admin_page_base_on_error ((TubaViewsAdminPageBase*) _data_->self, _data_->_tmp39_->code, _data_->_tmp41_);
				_g_error_free0 (_data_->e);
			}
			__finally0:
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->req);
				_g_object_unref0 (_data_->dlg);
				_g_free0 (_data_->domain);
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
				g_clear_error (&_data_->_inner_error0_);
				g_object_unref (_data_->_async_result);
				return FALSE;
			}
			_g_object_unref0 (_data_->req);
		}
		_g_object_unref0 (_data_->dlg);
		_g_free0 (_data_->domain);
	}
	_data_->_tmp43_ = 0;
	_data_->_tmp42_ = string_get_data ("", &_data_->_tmp43_);
	_data_->_tmp42__length1 = _data_->_tmp43_;
	_data_->_tmp44_ = _data_->_tmp42_;
	_data_->_tmp44__length1 = _data_->_tmp42__length1;
	gtk_entry_buffer_set_text (_data_->buffer, (const char*) _data_->_tmp44_, (gint) _data_->_tmp44__length1);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

TubaViewsAdminPageBlockedEmails*
tuba_views_admin_page_blocked_emails_construct (GType object_type)
{
	TubaViewsAdminPageBlockedEmails * self = NULL;
	self = (TubaViewsAdminPageBlockedEmails*) tuba_views_admin_page_base_construct (object_type);
	return self;
}

TubaViewsAdminPageBlockedEmails*
tuba_views_admin_page_blocked_emails_new (void)
{
	return tuba_views_admin_page_blocked_emails_construct (TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS);
}

static void
_tuba_views_admin_page_blocked_emails_new_item_cb_gtk_button_clicked (GtkButton* _sender,
                                                                      gpointer self)
{
	tuba_views_admin_page_blocked_emails_new_item_cb ((TubaViewsAdminPageBlockedEmails*) self);
}

static void
_tuba_views_admin_page_blocked_emails_new_item_cb_gtk_entry_activate (GtkEntry* _sender,
                                                                      gpointer self)
{
	tuba_views_admin_page_blocked_emails_new_item_cb ((TubaViewsAdminPageBlockedEmails*) self);
}

static void
_tuba_views_admin_page_blocked_emails_on_entry_changed_g_object_notify (GObject* _sender,
                                                                        GParamSpec* pspec,
                                                                        gpointer self)
{
	tuba_views_admin_page_blocked_emails_on_entry_changed ((TubaViewsAdminPageBlockedEmails*) self);
}

static void
_tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error (TubaViewsAdminTimelinePaginationTimeline* _sender,
                                                                                             gint code,
                                                                                             const gchar* message,
                                                                                             gpointer self)
{
	tuba_views_admin_page_base_on_error ((TubaViewsAdminPageBase*) self, code, message);
}

static GObject *
tuba_views_admin_page_blocked_emails_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminPageBlockedEmails * self;
	GtkActionBar* add_action_bar = NULL;
	gchar* _tmp0_;
	gchar** _tmp1_;
	GtkActionBar* _tmp2_ = NULL;
	gchar* _tmp3_;
	GtkEntry* _tmp4_ = NULL;
	GtkBox* child_box = NULL;
	GtkBox* _tmp5_;
	GtkButton* _tmp6_ = NULL;
	GtkButton* _tmp7_;
	GtkEntry* _tmp8_;
	GtkEntry* _tmp9_;
	GtkBox* _tmp10_;
	GtkEntry* _tmp11_;
	GtkBox* _tmp12_;
	GtkButton* _tmp13_;
	GtkActionBar* _tmp14_;
	GtkBox* _tmp15_;
	AdwToolbarView* _tmp16_;
	GtkActionBar* _tmp17_;
	TubaViewsAdminTimelineEmailDomain* _tmp18_;
	TubaViewsAdminTimelineEmailDomain* _tmp19_;
	TubaViewsAdminTimelineEmailDomain* _tmp20_;
	TubaViewsAdminTimelineEmailDomain* _tmp21_;
	TubaViewsAdminTimelineEmailDomain* _tmp22_;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_page_blocked_emails_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmails);
	adw_navigation_page_set_title ((AdwNavigationPage*) self, _ ("Blocked E-mail Domains"));
	_tmp0_ = g_strdup ("ttl-box-no-shadow");
	_tmp1_ = g_new0 (gchar*, 1 + 1);
	_tmp1_[0] = _tmp0_;
	_tmp2_ = (GtkActionBar*) gtk_action_bar_new ();
	gtk_widget_set_css_classes ((GtkWidget*) _tmp2_, _tmp1_);
	_tmp1_ = (_vala_array_free (_tmp1_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp2_);
	add_action_bar = _tmp2_;
	_tmp3_ = g_strdup (_ ("Block a new e-mail domain"));
	_tmp4_ = (GtkEntry*) gtk_entry_new ();
	gtk_entry_set_input_purpose (_tmp4_, GTK_INPUT_PURPOSE_URL);
	gtk_entry_set_placeholder_text (_tmp4_, _tmp3_);
	_g_free0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->child_entry);
	self->priv->child_entry = _tmp4_;
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp5_);
	child_box = _tmp5_;
	_tmp6_ = (GtkButton*) gtk_button_new_with_label (_ ("Block"));
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, FALSE);
	g_object_ref_sink (_tmp6_);
	_g_object_unref0 (self->priv->add_button);
	self->priv->add_button = _tmp6_;
	_tmp7_ = self->priv->add_button;
	g_signal_connect_object (_tmp7_, "clicked", (GCallback) _tuba_views_admin_page_blocked_emails_new_item_cb_gtk_button_clicked, self, 0);
	_tmp8_ = self->priv->child_entry;
	g_signal_connect_object (_tmp8_, "activate", (GCallback) _tuba_views_admin_page_blocked_emails_new_item_cb_gtk_entry_activate, self, 0);
	_tmp9_ = self->priv->child_entry;
	g_signal_connect_object ((GObject*) _tmp9_, "notify::text", (GCallback) _tuba_views_admin_page_blocked_emails_on_entry_changed_g_object_notify, self, 0);
	_tmp10_ = child_box;
	_tmp11_ = self->priv->child_entry;
	gtk_box_append (_tmp10_, (GtkWidget*) _tmp11_);
	_tmp12_ = child_box;
	_tmp13_ = self->priv->add_button;
	gtk_box_append (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = add_action_bar;
	_tmp15_ = child_box;
	gtk_action_bar_set_center_widget (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = ((TubaViewsAdminPageBase*) self)->toolbar_view;
	_tmp17_ = add_action_bar;
	adw_toolbar_view_add_top_bar (_tmp16_, (GtkWidget*) _tmp17_);
	_tmp18_ = tuba_views_admin_timeline_email_domain_new ();
	g_object_ref_sink (_tmp18_);
	_g_object_unref0 (self->priv->pagination_timeline);
	self->priv->pagination_timeline = _tmp18_;
	_tmp19_ = self->priv->pagination_timeline;
	g_signal_connect_object ((TubaViewsAdminTimelinePaginationTimeline*) _tmp19_, "on-error", (GCallback) _tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error, (TubaViewsAdminPageBase*) self, 0);
	_tmp20_ = self->priv->pagination_timeline;
	g_object_bind_property_with_closures ((GObject*) _tmp20_, "working", (GObject*) self, "spinning", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp21_ = self->priv->pagination_timeline;
	tuba_views_admin_page_base_set_page ((TubaViewsAdminPageBase*) self, (GtkWidget*) _tmp21_);
	_tmp22_ = self->priv->pagination_timeline;
	tuba_views_admin_timeline_pagination_timeline_request ((TubaViewsAdminTimelinePaginationTimeline*) _tmp22_, NULL, NULL);
	_g_object_unref0 (child_box);
	_g_object_unref0 (add_action_bar);
	return obj;
}

static void
tuba_views_admin_page_blocked_emails_class_init (TubaViewsAdminPageBlockedEmailsClass * klass,
                                                 gpointer klass_data)
{
	tuba_views_admin_page_blocked_emails_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageBlockedEmails_private_offset);
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_page_blocked_emails_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_blocked_emails_finalize;
}

static void
tuba_views_admin_page_blocked_emails_instance_init (TubaViewsAdminPageBlockedEmails * self,
                                                    gpointer klass)
{
	self->priv = tuba_views_admin_page_blocked_emails_get_instance_private (self);
}

static void
tuba_views_admin_page_blocked_emails_finalize (GObject * obj)
{
	TubaViewsAdminPageBlockedEmails * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmails);
	_g_object_unref0 (self->priv->child_entry);
	_g_object_unref0 (self->priv->add_button);
	_g_object_unref0 (self->priv->pagination_timeline);
	G_OBJECT_CLASS (tuba_views_admin_page_blocked_emails_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_blocked_emails_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageBlockedEmailsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_blocked_emails_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageBlockedEmails), 0, (GInstanceInitFunc) tuba_views_admin_page_blocked_emails_instance_init, NULL };
	GType tuba_views_admin_page_blocked_emails_type_id;
	tuba_views_admin_page_blocked_emails_type_id = g_type_register_static (TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, "TubaViewsAdminPageBlockedEmails", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageBlockedEmails_private_offset = g_type_add_instance_private (tuba_views_admin_page_blocked_emails_type_id, sizeof (TubaViewsAdminPageBlockedEmailsPrivate));
	return tuba_views_admin_page_blocked_emails_type_id;
}

GType
tuba_views_admin_page_blocked_emails_get_type (void)
{
	static GType tuba_views_admin_page_blocked_emails_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_blocked_emails_type_id__once)) {
		GType tuba_views_admin_page_blocked_emails_type_id;
		tuba_views_admin_page_blocked_emails_type_id = tuba_views_admin_page_blocked_emails_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_blocked_emails_type_id__once, tuba_views_admin_page_blocked_emails_type_id);
	}
	return tuba_views_admin_page_blocked_emails_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

